#!/bin/sh
#v3.1 
#2020-09-02 
#check intervel
gInterval=60
#log check days >= 1
gLogCheckDay=7

LOGPATH=/var/log/monitor/lw_collect_rt
hasTc=1
hasMpstat=1
hasArp=1
hasSar=1

checkLogFile()
{
    find $LOGPATH -type f -name *.log -mtime +$gLogCheckDay -exec rm -- '{}' \; 
}

updateLogFile()
{
    local logSufix
    logSufix=$(date +'%Y%m%d')

    gLogFileName=lw_collect_rt-${logSufix}.log
    gLogFile=$LOGPATH/$gLogFileName
}

is_exist=`ps | grep "$0" | grep -v grep | wc -l` > /dev/null
if [ $is_exist -gt 2 ];then
    echo "$0 already Running"
    exit 1
fi

if [ ! -d ${LOGPATH} ]; then
    mkdir -p ${LOGPATH} 2>/dev/null
fi

if [ -d /proc/ltt ];then
    LTTPATH=/proc/ltt
elif [ -d /proc/net/lightwan/ltt ];then
    LTTPATH=/proc/net/lightwan/ltt
fi

[ -z `which tc` ] && {
    hasTc=0
} 
[ -z `which mpstat` ] && {
    hasMpstat=0
}
[ -z `which arp` ] && {
    hasArp=0
}
[ -z `which sar` ] && {
    hasSar=0
}

if [ ${gLogCheckDay} -lt 1 ];then
    gLogCheckDay=0
else
    gLogCheckDay=`expr ${gLogCheckDay} - 1`
fi

while true; do
    updateLogFile
    checkLogFile
    echo ============================== >> $gLogFile
    date >> $gLogFile
    # stats
    echo ---------LTT----------------- >> $gLogFile
    cat $LTTPATH/stats >> $gLogFile
    echo >> $gLogFile
    cat $LTTPATH/lsw-tbl >> $gLogFile
    echo >> $gLogFile
    cat $LTTPATH/tunnels >> $gLogFile
    echo >> $gLogFile
    cat $LTTPATH/link-tbl >> $gLogFile
    echo >> $gLogFile
    cat $LTTPATH/local-iptbl >> $gLogFile
    echo >> $gLogFile
    cat $LTTPATH/cpe-iptbl >> $gLogFile
    echo >> $gLogFile
    cat $LTTPATH/pop-iptbl >> $gLogFile
    echo >> $gLogFile

    #ifconfig
    echo -----------ifconfig-------------- >> $gLogFile
    ifconfig >> $gLogFile

    #interrupt
    echo -----------/proc/interrupts----------- >> $gLogFile
    grep eth /proc/interrupts >> $gLogFile

    # qdisc
    [ ${hasSar} -eq 1 ] && {
        echo ---------------qdisc----------- >> $gLogFile
        tc -s qdisc show >> $gLogFile
    }

    #memory
    echo ---------------memory----------- >> $gLogFile
    free >> $gLogFile

    #cpustats
    [ ${hasMpstat} -eq 1 ] && {
        echo ---------------cpu stats----------- >> $gLogFile
        mpstat -P ALL >> $gLogFile
    }

    #disk usage
    echo ---------------disk usage----------- >> $gLogFile
    df -h >> $gLogFile

    #route
    echo ---------------route----------- >> $gLogFile
    route -n >> $gLogFile

    #arp
    [ ${hasArp} -eq 1 ] && {
        echo ---------------arp----------- >> $gLogFile
        arp -n >> $gLogFile  
    }

    #engine stats
    appexlist=`ls /proc/net/appex* -d`
    count=0
    for DR in $appexlist
        do
        let "count++"
    done
    num=`expr $count - 1`

    for i in $(seq 0 ${num});
    do
        echo ------------appex$i stats-------- >> $gLogFile
        if [ $i -eq 0 ];then
            echo displayLevel: 10 > /proc/net/appex/cmd
            cat /proc/net/appex/stats >> $gLogFile
        else
            echo displayLevel: 10 > /proc/net/appex$i/cmd
            cat /proc/net/appex$i/stats >> $gLogFile
        fi
    done

    #sar 
    [ ${hasSar} -eq 1 ] && {
        echo -----------sar report---------- >> $gLogFile
        sar -n DEV,EDEV 1 1 >> $gLogFile
    }

    sleep ${gInterval}
done
